==> ecomero-erpcore-1.2.48.zip: Model/Erp/ErpOrder.php <==
<?php

declare(strict_types=1);
/**
 *           a88888P8
 *          d8'
 * .d8888b. 88        .d8888b. 88d8b.d8b. .d8888b. .dd888b. .d8888b.
 * 88ooood8 88        88'  `88 88'`88'`88 88ooood8 88'    ` 88'  `88
 * 88.  ... Y8.       88.  .88 88  88  88 88.  ... 88       88.  .88
 * `8888P'   Y88888P8 `88888P' dP  dP  dP `8888P'  dP       `88888P'.
 *
 *           Copyright © eComero Management AB, All rights reserved.
 */

namespace Ecomero\ErpCore\Model\Erp;

use Ecomero\ErpCore\Model\Order\Response;
use Magento\Sales\Model\Order\Address;

class ErpOrder extends ErpAdapter implements ErpOrderInterface
{
    public function getSalesPersons(): array
    {
        return [];
    }

    public function getProfitCenters(): array
    {
        return [];
    }

    public function getDocumentFromExternalId(string $docType, string $magentoOrderId): object
    {
        return (object) null;
    }

    public function createDocument(string $docType, string $customerId, ?string $companyId, string $currency, Address $billingAddress, Address $shippingAddress, ?string $shippingAgent, ?string $shippingService, ?string $shippingPickupLocationId, string $magentoOrderId, string $salesPerson, ?string $profitCenter, ?string $termsOfDelivery, ?string $wayOfDelivery, ?string $customerCategory, ?string $customerDistrict): Response
    {
        return new Response([]);
    }

    public function updateDocument(string $docType, string $erpId, string $magentoOrderId): Response
    {
        return new Response([]);
    }

    public function addDocumentItem(string $docType, string $orderNumber, string $erpItemId, float $price, float $qtyOrdered, string $vatCode, float $discountAmount, float $discountPercent, ?string $comment, ?string $locationId): void
    {
    }

    public function postOrder(string $salesOrderId): void
    {
    }
}

==> ecomero-erpcore-1.2.69.zip: Model/Erp/ErpOrder.php <==
<?php

declare(strict_types=1);
/**
 *           a88888P8
 *          d8'
 * .d8888b. 88        .d8888b. 88d8b.d8b. .d8888b. .dd888b. .d8888b.
 * 88ooood8 88        88'  `88 88'`88'`88 88ooood8 88'    ` 88'  `88
 * 88.  ... Y8.       88.  .88 88  88  88 88.  ... 88       88.  .88
 * `8888P'   Y88888P8 `88888P' dP  dP  dP `8888P'  dP       `88888P'.
 *
 *           Copyright © eComero Management AB, All rights reserved.
 */

namespace Ecomero\ErpCore\Model\Erp;

use Ecomero\ErpCore\Model\Order\Response;
use Magento\Sales\Model\Order\Address;

class ErpOrder extends ErpAdapter implements ErpOrderInterface
{
    public function getSalesPersons(): array
    {
        return [];
    }

    public function getProfitCenters(): array
    {
        return [];
    }

    public function getDocumentFromExternalId(string $docType, string $magentoOrderId): object
    {
        return (object) null;
    }

    public function createDocument(
        string $docType,
        ?string $customerId,
        ?string $companyId,
        string $currency,
        Address $billingAddress,
        Address $shippingAddress,
        ?string $shippingAgent,
        ?string $shippingService,
        ?string $shippingPickupLocationId,
        string $magentoOrderId,
        ?string $extPONumber,
        string $salesPerson,
        ?string $profitCenter,
        ?string $termsOfDelivery,
        ?string $wayOfDelivery,
        ?string $customerCategory,
        ?string $customerDistrict
    ): Response {
        return new Response([]);
    }

    public function updateDocument(string $docType, string $erpId, string $magentoOrderId): Response
    {
        return new Response([]);
    }

    public function addDocumentItem(string $docType, string $orderNumber, string $erpItemId, float $price, float $qtyOrdered, string $vatCode, float $discountAmount, float $discountPercent, ?string $comment, ?string $locationId): void
    {
    }

    public function postOrder(string $salesOrderId): void
    {
    }
}
